# SPDX-FileCopyrightText: 2017-2020 Tobias Leupold <tobias.leupold@gmx.de>
#
# SPDX-License-Identifier: BSD-3-Clause

if (EXISTS "${BASE_DIR}/.git")
    find_package(Git QUIET)
endif()

set(RSTFILE "${BASE_DIR}/doc/Readme.rst")
set(CSSFILE "${BASE_DIR}/doc/Readme.css")

if (GIT_FOUND)
    execute_process(COMMAND ${GIT_EXECUTABLE} --no-pager log -1 --format=%ad
                            --date=format:%d.%m.%Y -- ${RSTFILE}
                    OUTPUT_VARIABLE LASTCHANGE
                    OUTPUT_STRIP_TRAILING_WHITESPACE)
    include(${CMAKE_CURRENT_LIST_DIR}/GitDescription.cmake)
    git_get_description(VERSION GIT_ARGS)
    message(STATUS "Setting the Readme's last changed date to ${LASTCHANGE}")
    configure_file(${RSTFILE} ${CMAKE_BINARY_DIR}/Readme.rst)
    set(RSTFILE "Readme.rst")
else()
    message(STATUS "Using the released RST Readme")
endif()

message(STATUS "Converting the Readme from RST to HTML")
execute_process(COMMAND ${RST2HTML5} --stylesheet=minimal.css,${CSSFILE}
                        "${RSTFILE}" "share/muckturnier/Readme.htm"
                WORKING_DIRECTORY ${CMAKE_BINARY_DIR})
