/* SPDX-FileCopyrightText: 2010-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

// Local includes

#include "AboutDialog.h"

#include "shared/SharedStyles.h"
#include "shared/SharedObjects.h"
#include "shared/Database.h"
#include "shared/ResourceFinder.h"
#include "shared/TournamentSettings.h"
#include "shared/Urls.h"

#include "network/ServerProtocol.h"

#include "version.h"

// Qt includes
#include <QVBoxLayout>
#include <QGroupBox>
#include <QLabel>
#include <QDebug>
#include <QIcon>
#include <QDate>

AboutDialog::AboutDialog(QWidget *parent, SharedObjects *sharedObjects) : TitleDialog(parent)
{
    setWindowTitle(tr("Über Muckturnier"));
    addButtonBox(QDialogButtonBox::Ok);
    mainLayout()->setSizeConstraint(QLayout::SetFixedSize);

    const QDate compilerDate = QLocale(QStringLiteral("en_US")).toDate(
        QStringLiteral(__DATE__).simplified(), QStringLiteral("MMM d yyyy"));

    QVBoxLayout *headerLayout = new QVBoxLayout;
    headerLayout->setSpacing(0);
    layout()->addLayout(headerLayout);

    QLabel *banner = new QLabel;
    banner->setPixmap(QPixmap(sharedObjects->resourceFinder()->find(QStringLiteral("banner.png"))));
    banner->setAlignment(Qt::AlignCenter);
    banner->setStyleSheet(SharedStyles::headerLogo);
    banner->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Maximum);
    headerLayout->addWidget(banner);

    QLabel *subtitle = new QLabel(tr("Das Programm für die Turnierleitung"));
    subtitle->setStyleSheet(SharedStyles::footerLogo);
    subtitle->setAlignment(Qt::AlignCenter);
    headerLayout->addWidget(subtitle);

    QGroupBox *versionBox = new QGroupBox;
    versionBox->setProperty("notitle", true);
    QVBoxLayout *versionBoxLayout = new QVBoxLayout(versionBox);
    layout()->addWidget(versionBox);

    QLabel *version = new QLabel(
          tr("<div syle=\"text-align: center;\"><b>Version %1 (%2)</b></div>").arg(
             QLatin1String(MT_VERSION), compilerDate.toString(QLatin1String("dd.MM.yyyy")))
          + QLatin1String("<div style=\"text-align: center;\"><table>")
          + tr("<tr><td>Datenbank:</td><td>Revision %1</td></tr>").arg(
               sharedObjects->database()->dbVersion())
          + tr("<tr><td>Einstellungen:</td><td>Revision %1</td></tr>").arg(
               sharedObjects->tournamentSettings()->version())
          + tr("<tr><td>Serverprotokoll:</td><td>Revision %1</td></tr>").arg(
               ServerProtocol::protocolVersion)
          + QLatin1String("</table></div>"));
    version->setAlignment(Qt::AlignCenter);
    version->setTextInteractionFlags(Qt::TextBrowserInteraction | Qt::TextSelectableByMouse);
    version->setOpenExternalLinks(true);
    versionBoxLayout->addWidget(version);

    QGroupBox *licenseBox = new QGroupBox;
    licenseBox->setProperty("notitle", true);
    QVBoxLayout *licenseBoxLayout = new QVBoxLayout(licenseBox);
    layout()->addWidget(licenseBox);

    QLabel *license = new QLabel(
        tr("<p>Quellcode veröffentlicht unter der<br/>"
           "<a href=\"https://www.gnu.org/licenses/#GPL\">GNU General Public License (GPL)</a></p>"
           "<p>Kompiliert gegen <a href=\"https://www.qt.io/\">Qt</a> %1</p>").arg(
           QLatin1String(QT_VERSION_STR)));

    license->setAlignment(Qt::AlignCenter);
    license->setTextInteractionFlags(Qt::TextBrowserInteraction | Qt::TextSelectableByMouse);
    license->setOpenExternalLinks(true);
    licenseBoxLayout->addWidget(license);

    QGroupBox *authorBox = new QGroupBox;
    authorBox->setProperty("notitle", true);
    QVBoxLayout *authorBoxLayout = new QVBoxLayout(authorBox);
    layout()->addWidget(authorBox);

    QLabel *author = new QLabel(tr("Copyright %1 2010–%2 Tobias Leupold").arg(
                                   QStringLiteral("\u00A9"), QString::number(compilerDate.year()))
                                + tr("<br/>"
                                     "<a href=\"%1\">%1</a>").arg(Urls::homepage));
    author->setAlignment(Qt::AlignCenter);
    author->setTextInteractionFlags(Qt::TextBrowserInteraction | Qt::TextSelectableByMouse);
    author->setOpenExternalLinks(true);
    authorBoxLayout->addWidget(author);
}
