/* SPDX-FileCopyrightText: 2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

#ifndef ADJUSTDRAWDIALOG_H
#define ADJUSTDRAWDIALOG_H

// Local includes
#include "shared/TitleDialog.h"
#include "shared/Draw.h"

// Qt includes
#include <QHash>

// Qt classes
class QTableWidget;

class AdjustDrawDialog : public TitleDialog
{
    Q_OBJECT

public:
    explicit AdjustDrawDialog(QWidget *parent,
                              const QVector<QString> &allRegistrations,
                              const QVector<Draw::Seat> &allDraws,
                              bool isPairMode,
                              QString namesSeparator);

public slots:
    void listWasModified();

signals:
    void adoptAdjustment(const QVector<QString> &names, const QVector<Draw::Seat> &seats);

private: // Functions
    QVector<int> findIncompletePairs(int pair, QVector<QVector<QString>> &draw) const;
    bool compilePairsSameRole(int pair, QVector<QVector<QString>> &draw);
    bool compilePairsSwitchRole(int pair, QVector<QVector<QString>> &draw);
    QVector<int> findSinglePairs(int pair, QVector<QVector<QString>> &draw) const;
    bool compileOpponentPairs(int pair, QVector<QVector<QString>> &draw);
    bool compileSameTypePairs(int pair, QVector<QVector<QString>> &draw);
    bool fillTableGaps(QVector<QVector<QString>> &draw);

private slots:
    void resizeView();
    void printList();

private: // Variables
    int m_tables;
    QTableWidget *m_changes;
    QHash<QString, Draw::Seat> m_moved;
    QVector<QString> m_names;
    QVector<Draw::Seat> m_newSeats;

};

#endif // ADJUSTDRAWDIALOG_H
