/* SPDX-FileCopyrightText: 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

#ifndef CHECKSUMSDIALOG_H
#define CHECKSUMSDIALOG_H

// Local includes
#include "shared/TitleDialog.h"
#include "shared/TournamentSettings.h"
#include "shared/Database.h"

// Local classes
class SharedObjects;
class TournamentSettings;

// Qt classes
class QLabel;
class QPushButton;
class QTableWidget;
class QGroupBox;

class ChecksumsDialog : public TitleDialog
{
    Q_OBJECT

public:
    explicit ChecksumsDialog(QWidget *parent, SharedObjects *sharedObjects);

private slots:
    void showPartialChecksums();
    void divideFirstPart();
    void divideSecondPart();
    void resetPartialChecksums();

private: // Functions
    QString formatChecksum(QString checksum) const;
    QString rankingChecksum(int startRow, int rowCount) const;
    void updateDividedChecksums();
    QTableWidget *createTableWidget();
    void updateRankingTable(QTableWidget *table, int startRow, int rowCount);

private: // Variables
    Database *m_db;
    TournamentSettings *m_tournamentSettings;

    QVector<Database::RankData> m_ranking;
    int m_firstStartRow;
    int m_secondStartRow;
    int m_firstRowCount;
    int m_secondRowCount;
    QPushButton *m_showPartialChecksums;
    QGroupBox *m_partialChecksumsBox;
    QGroupBox *m_firstPartBox;
    QLabel *m_firstPartChecksum;
    QGroupBox *m_secondPartBox;
    QLabel *m_secondPartChecksum;
    QPushButton *m_divideFirstPart;
    QPushButton *m_divideSecondPart;
    QPushButton *m_reset;
    QTableWidget *m_firstPartRanking;
    QTableWidget *m_secondPartRanking;

};

#endif // CHECKSUMSDIALOG_H
