/* SPDX-FileCopyrightText: 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

#ifndef COMPARERANKINGDIALOG_H
#define COMPARERANKINGDIALOG_H

// Local includes
#include "shared/TitleDialog.h"
#include "shared/Database.h"

// Local classes
class SharedObjects;
class TournamentSettings;
class StringTools;

// Qt classes
class QLabel;
class QTableWidget;
class QPushButton;

class CompareRankingDialog : public TitleDialog
{
    Q_OBJECT

public:
    explicit CompareRankingDialog(QWidget *parent, SharedObjects *sharedObjects);
    void compareRanking(const QVector<Database::RankData> &remoteRanking);

public slots:
    void clientDisconnected();
    void dataChanged();

signals:
    void rankingRequested();

private: // Functions
    void requestRanking();
    void dataReceived();
    const QString differenceString(int local, int remote) const;
    void resizeToTableSize();
    void finishDisplayDifferences();
    bool checkTournamentStarted();

private: // Variables
    Database *m_db;
    TournamentSettings *m_tournamentSettings;
    StringTools *m_stringTools;

    QLabel *m_dataChangedLabel;
    QLabel *m_resultLabel;
    QTableWidget *m_differences;
    QPushButton *m_requestRanking;
    QPushButton *m_close;

};

#endif // COMPARERANKINGDIALOG_H
