/* SPDX-FileCopyrightText: 2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

#ifndef COMPARESCOREDIALOG_H
#define COMPARESCOREDIALOG_H

// Local includes
#include "shared/TitleDialog.h"
#include "shared/Scores.h"

// Local classes
class SharedObjects;
class Database;
class TournamentSettings;
class StringTools;
class Client;

// Qt classes
class QLabel;
class QTableWidget;
class QPushButton;
class QTableWidget;

class CompareScoreDialog : public TitleDialog
{
    Q_OBJECT

public:
    explicit CompareScoreDialog(QWidget *parent, SharedObjects *SharedObjects, Client *client,
                                const int *currentRound);

public slots:
    void clientDisconnected();
    void remoteChecksumChanged(int round);
    void dataChanged();
    void compareScore(Scores::Score &remoteScore);

signals:
    void scoreRequested(int round);

private slots:
    void requestScore();

private: // Functions
    void resizeToTableSize();

private: // Variables
    struct Id
    {
        int remote;
        int local;
    };

    Database *m_db;
    TournamentSettings *m_tournamentSettings;
    StringTools *m_stringTools;
    Client *m_client;
    const int *m_currentRound;

    QPushButton *m_request;
    QPushButton *m_close;
    QLabel *m_requesting;
    QLabel *m_differencesLabel;
    QLabel *m_noDifferencesLabel;
    QTableWidget *m_differences;
    QLabel *m_dataChangedLabel;

};

#endif // COMPARESCOREDIALOG_H
