/* SPDX-FileCopyrightText: 2010-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

#ifndef EXPORTTOURNAMENTDIALOG_H
#define EXPORTTOURNAMENTDIALOG_H

// Local includes
#include "shared/FileDialog.h"
#include "shared/Database.h"

// Qt classes
class QTextStream;

// Local classes
class SharedObjects;
class StringTools;
class TournamentSettings;
class BasicExportPage;
class ExportDatasetsPage;
class ExportFormattingPage;

class ExportTournamentDialog : public FileDialog
{
    Q_OBJECT

public:
    explicit ExportTournamentDialog(QWidget *parent, SharedObjects *SharedObjects);

private: // Functions
    struct GoalsData
    {
        QString goals;
        QString opponentGoals;
    };

    void saveHtmlFile(QTextStream &outStream);
    void saveHtmlHorizontalRoundResults(QTextStream &outStream);
    void saveHtmlVerticalRoundResults(QTextStream &outStream);
    void saveCsvFile(QTextStream &outStream);
    void saveCsvHorizontalRoundResults(QTextStream &outStream);
    void saveCsvVerticalRoundResults(QTextStream &outStream);

    QVector<GoalsData> prepareGoals(const QVector<Database::RankData> &ranking) const;
    QString displayScore(int score) const;

private slots:
    void accept() override;
    void checkExportPossible();

private: // Variables
    Database *m_db;
    StringTools *m_stringTools;
    TournamentSettings *m_tournamentSettings;
    const QString m_dateFormat;
    const QString m_timeFormat;

    BasicExportPage *m_basicExportPage;
    ExportDatasetsPage *m_exportDatasetsPage;
    ExportFormattingPage *m_exportFormattingPage;

};

#endif // EXPORTTOURNAMENTDIALOG_H
