/* SPDX-FileCopyrightText: 2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

// Local includes

#include "DrawSettingsPage.h"

#include "shared/TournamentTemplate.h"
#include "shared/TournamentSettings.h"
#include "shared/DrawSettingsWidget.h"

// Qt includes
#include <QVBoxLayout>
#include <QLabel>

DrawSettingsPage::DrawSettingsPage(const TournamentTemplate::Settings &tournamentTemplate,
                                   TournamentSettings *tournamentSettings,
                                   QWidget *parent)
    : AbstractSettingsPage(tr("Auslosung"), parent),
      m_tournamentSettings(tournamentSettings)
{
    QLabel *drawSettingsLabel = new QLabel(tr(
        "Die hier einstellbaren Optionen können auf der „Anmeldung“-Seite (via „Einstellungen“ → "
        "„Einstellungen für die Auslosung“) beliebig verändert werden, auch während des "
        "Turniers."));
    drawSettingsLabel->setWordWrap(true);
    layout()->addWidget(drawSettingsLabel);

    m_drawSettingsWidget = new DrawSettingsWidget;
    m_drawSettingsWidget->updateSettings(tournamentTemplate.drawSettings);
    layout()->addWidget(m_drawSettingsWidget);

    auto *drawOverviewLabel = new QLabel(tr("Für die „Übersicht Auslosung“-Seite siehe "
                                            "<a href=\"#raiseOptionalPages\">Optionale "
                                            "Seiten</a>!"));
    drawOverviewLabel->setWordWrap(true);
    drawOverviewLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
    connect(drawOverviewLabel, &QLabel::linkActivated, this, &DrawSettingsPage::linkActivated);
    layout()->addWidget(drawOverviewLabel);

    layout()->addStretch();
}

void DrawSettingsPage::saveSettings()
{
    m_tournamentSettings->setDrawSettings(m_drawSettingsWidget->settings());
}
