/* SPDX-FileCopyrightText: 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

// Local includes

#include "RegistrationSettingsPage.h"

#include "shared/TournamentTemplate.h"
#include "shared/TournamentSettings.h"

// Qt includes
#include <QDebug>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QLabel>
#include <QCheckBox>
#include <QGroupBox>
#include <QMessageBox>
#include <QFrame>

RegistrationSettingsPage::RegistrationSettingsPage(
    const TournamentTemplate::Settings &tournamentTemplate,
    TournamentSettings *tournamentSettings,
    QWidget *parent)
    : AbstractSettingsPage(tr("Anmeldung"), parent),
      m_tournamentSettings(tournamentSettings)
{
    auto *inputSettingsLabel = new QLabel(tr("Die hier einstellbaren Optionen können auf der "
                                             "„Anmeldung“-Seite beliebig verändert werden, auch "
                                             "während des Turniers."));
    inputSettingsLabel->setWordWrap(true);
    layout()->addWidget(inputSettingsLabel);

    auto *columnsBox = new QGroupBox(tr("Spalten der Anmeldeseite"));

    auto *columnsBoxLayout = new QVBoxLayout(columnsBox);
    auto *header = new QLabel(tr("Neben der „Name“-Spalte werden zu Beginn folgende Spalten "
                                 "eingeblendet:"));
    header->setWordWrap(true);
    columnsBoxLayout->addWidget(header);

    auto *checkBoxesLayout = new QHBoxLayout;
    columnsBoxLayout->addLayout(checkBoxesLayout);

    layout()->addWidget(columnsBox);

    for (const RegistrationColumns::Column column : RegistrationColumns::allColumns) {
        auto *checkBox = new QCheckBox(tr(RegistrationColumns::checkBoxText.value(column)));
        m_column[column] = checkBox;
        checkBox->setChecked(tournamentTemplate.registrationColumns.contains(column));
        checkBoxesLayout->addWidget(checkBox);
    }
    connect(m_column.value(RegistrationColumns::Column::Draw), &QCheckBox::toggled,
            this, &RegistrationSettingsPage::drawColumnShown);

    auto *drawOverviewLabel = new QLabel(tr("Für die „Übersicht Auslosung“-Seite siehe "
                                            "<a href=\"#raiseOptionalPages\">Optionale "
                                            "Seiten</a>!"));
    drawOverviewLabel->setWordWrap(true);
    drawOverviewLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
    connect(drawOverviewLabel, &QLabel::linkActivated,
            this, &RegistrationSettingsPage::linkActivated);
    columnsBoxLayout->addWidget(drawOverviewLabel);

    auto *line = new QFrame;
    line->setFrameShape(QFrame::HLine);
    columnsBoxLayout->addWidget(line);

    m_headerHidden = new QCheckBox(tr("Spalten-Kopfzeile ausblenden"));
    m_headerHidden->setChecked(tournamentTemplate.registrationListHeaderHidden);
    columnsBoxLayout->addWidget(m_headerHidden);

    auto *markersBox = new QGroupBox(tr("Vorlage und Einstellungen für Markierungen"));
    auto *markersBoxLayout = new QVBoxLayout(markersBox);
    layout()->addWidget(markersBox);

    auto *markers = new QLabel(tr(
        "<p>Die Vorlage für Markierungen und Einstellungen zur Behandlung allein gekommener "
        "Spieler etc. kann aus einem laufenden Turnier erzeugt werden.</p>"
        "<p>Via „Extras“ → „Einstellungen“ → „Vorlage Markierungen“ können die aktuellen "
        "Einstellungen übernommen und gespeichert werden.</p>"));
    markers->setWordWrap(true);
    markersBoxLayout->addWidget(markers);

    layout()->addStretch();
}

void RegistrationSettingsPage::saveSettings()
{
    QVector<RegistrationColumns::Column> columns;
    for (const RegistrationColumns::Column column : RegistrationColumns::allColumns) {
        if (m_column[column]->isChecked()) {
            columns.append(column);
        }
    }
    m_tournamentSettings->setRegistrationColumns(columns);
    m_tournamentSettings->setRegistrationListHeaderHidden(m_headerHidden->isChecked());
}

void RegistrationSettingsPage::drawOverviewPageSelected(bool state)
{
    m_drawOverviewPageSelected = state;
}

void RegistrationSettingsPage::drawColumnShown(bool state)
{
    if (! state
        || m_drawOverviewPageSelected
        || QMessageBox::question(this,
               tr("Spalte „Auslosung einblenden“"),
               tr("Soll die „Übersicht Auslosung“-Seite auch gleich zu Beginn eingeblendet "
                  "werden?"))
           != QMessageBox::Yes) {

        return;

    } else {
        emit showDrawOverviewPage();
    }
}
