/* SPDX-FileCopyrightText: 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

// Local includes
#include "MarkersPopup.h"

// Qt includes
#include <QDebug>
#include <QVBoxLayout>
#include <QPushButton>

// C++ includes
#include <functional>

MarkersPopup::MarkersPopup(QWidget *parent) : SelectionPopup(parent)
{
}

void MarkersPopup::show(const int currentMarker, const QPoint &position)
{
    const auto allPushButtons = findChildren<QPushButton *>();
    for (QPushButton *button : allPushButtons) {
        button->setVisible(button->property("id").toInt() != currentMarker);
    }

    if (position == QPoint(-1, -1)) {
        SelectionPopup::show();
    } else {
        SelectionPopup::show(position);
    }
}

void MarkersPopup::updateMarkers(const QVector<Markers::Marker> &markers)
{
    auto *widget = new QWidget;
    auto *layout = new QVBoxLayout(widget);
    layout->setSpacing(0);

    for (const Markers::Marker &marker : markers) {
        auto *button = new QPushButton(marker.name);

        if (marker.id != 0) {
            button->setStyleSheet(QStringLiteral("color:") + marker.color.name());
        }

        button->setProperty("id", QVariant(marker.id));
        layout->addWidget(button);

        connect(button, &QPushButton::clicked,
                std::bind(&MarkersPopup::markerSelected, this, button));
    }

    setScrollWidget(widget);
}

void MarkersPopup::markerSelected(QPushButton *button)
{
    m_markerId = button->property("id").toInt();
    m_markerName = m_markerId != 0 ? button->text() : QString();
    accept();
}

QString MarkersPopup::markerName() const
{
    return m_markerName;
}

int MarkersPopup::markerId() const
{
    return m_markerId;
}
