/* SPDX-FileCopyrightText: 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

#ifndef REGISTRATIONDELEGATE_H
#define REGISTRATIONDELEGATE_H

// Local includes
#include "shared/TableDelegate.h"

// Local classes
class PlayersEditor;

class RegistrationDelegate : public TableDelegate
{
    Q_OBJECT

public:
    explicit RegistrationDelegate(QObject *parent);
    bool isEditing() const;
    QString editedText() const;
    QString enteredText() const;
    void saveEditorState();
    void restoreEditorState();
    void abortEdit();

protected:
    QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &,
                          const QModelIndex &index) const override;
    void setModelData(QWidget *, QAbstractItemModel *, const QModelIndex &) const override;

signals:
    void startedEdit(int row) const;
    void editEntered(const QString &originalData, const QString &enteredData) const;

private:
    mutable bool m_isEditing = false;
    mutable PlayersEditor *m_editor;
    mutable QString m_originalData;
    QString m_enteredText;
    int m_cursorPosition;
    int m_selectionStart;
    int m_selectionLength;

};

#endif // REGISTRATIONDELEGATE_H
