/* SPDX-FileCopyrightText: 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

// Local includes

#include "Connection.h"

#include "network/ServerProtocol.h"

// Qt includes
#include <QDebug>
#include <QTcpSocket>
#include <QJsonDocument>
#include <QJsonObject>
#include <QDataStream>

namespace sp = ServerProtocol;

Connection::Connection(QObject *parent) : AbstractNetworkEngine(parent)
{
    connect(socket(), QOverload<QAbstractSocket::SocketError>::of(&QAbstractSocket::error),
            this, &Connection::error);
    connect(socket(), &QAbstractSocket::disconnected, this, &Connection::disconnected);
}

bool Connection::setSocketDescriptor(qintptr descriptor)
{
    return socket()->setSocketDescriptor(descriptor);
}

void Connection::close()
{
    socket()->abort();
    emit disconnected();
}

void Connection::dataReceived(const QString &action, const QJsonObject &jsonObject)
{
    if (action == sp::handshake) {
        processHandshake(jsonObject);
    } else {
        emit clientRequest(action, jsonObject);
    }
}

void Connection::processHandshake(const QJsonObject &jsonObject)
{
    const QJsonValue phaseValue = jsonObject.value(sp::phase);
    if (phaseValue.type() != QJsonValue::String) {
        emit handshakeResult(sp::failed);
        close();
        return;
    }
    emit handshakeResult(phaseValue.toString());
}

void Connection::setId(int id)
{
    m_id = id;
}

int Connection::id() const
{
    return m_id;
}
