/* SPDX-FileCopyrightText: 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

#ifndef MARKERSTEMPLATEPAGE_H
#define MARKERSTEMPLATEPAGE_H

// Local includes
#include "shared/AbstractSettingsPage.h"
#include "shared/Markers.h"

// Local classes
class SharedObjects;
class Database;
class Settings;
class TournamentSettings;

// Qt classes
class QTableWidget;
class QGroupBox;
class QLabel;
class QTableWidgetItem;

class MarkersTemplatePage : public AbstractSettingsPage
{
    Q_OBJECT

public:
    explicit MarkersTemplatePage(SharedObjects *sharedObjects, QWidget *parent = nullptr);
    void saveSettings() override;

private slots:
    void restoreTemplate();
    void adoptCurrentSettings();

private: // Functions
    void updateTemplateDisplay();
    const Markers::Marker &findMarker(int id) const;
    QString markerName(int id) const;
    QTableWidgetItem *markerItem(int id) const;

private: // Enums
    enum SettingsRow {
        Default,
        Drawn,
        Absent,
        Count
    };

private: // Variables
    Database *m_db;
    Settings *m_settings;
    TournamentSettings *m_tournamentSettings;

    QVector<Markers::Marker> m_markersTemplate;
    Markers::SinglesManagement m_singlesManagementTemplate;
    int m_defaultMarker;
    int m_drawnMarker;
    int m_absentMarker;

    QTableWidget *m_markersTemplateDisplay;
    QTableWidget *m_settingsDisplay;

    QLabel *m_noProcessSingles;
    QGroupBox *m_processSingles;
    QLabel *m_singlesMarker;
    QLabel *m_automaticMarking;
    QLabel *m_assignedMarker;

};

#endif // MARKERSTEMPLATEPAGE_H
