/* SPDX-FileCopyrightText: 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

// Local includes

#include "SaveOnClosePage.h"

#include "shared/Settings.h"

// Qt includes
#include <QDebug>
#include <QVBoxLayout>
#include <QHBoxLayout>
#include <QLabel>
#include <QCheckBox>
#include <QPushButton>
#include <QMessageBox>

SaveOnClosePage::SaveOnClosePage(Settings *settings, QWidget *parent)
    : AbstractSettingsPage(tr("Beim Beenden speichern"), parent),
      m_settings(settings)
{
    QLabel *saveOnCloseLabel = new QLabel(tr("Beim Beenden des können folgende Einstellungen "
                                             "gespeichert und beim nächsten Start "
                                             "wiederhergestellt werden:"));
    saveOnCloseLabel->setWordWrap(true);
    layout()->addWidget(saveOnCloseLabel);

    m_saveWindowGeometry = new QCheckBox(tr("Position und Größe des Programmfensters"));
    m_saveWindowGeometry->setChecked(m_settings->saveMainWindowGeometryEnabled());
    layout()->addWidget(m_saveWindowGeometry);

    m_saveWindowState = new QCheckBox(tr("Darstellung und Position der Seiten"));
    m_saveWindowState->setChecked(m_settings->saveMainWindowStateEnabled());
    layout()->addWidget(m_saveWindowState);

    m_saveLastDbPath = new QCheckBox(tr("Verzeichnis der letzten benutzen Turnierdatenbank\n"
                                        "(als Startpunkt des „Turnier öffnen“-Dateidialogs)"));
    m_saveLastDbPath->setChecked(m_settings->saveLastDbPathEnabled());
    layout()->addWidget(m_saveLastDbPath);

    m_saveStopWatchState = new QCheckBox(tr("Countdown-Zeit, Titel, Größe und Position der "
                                            "Stoppuhr"));
    m_saveStopWatchState->setChecked(m_settings->saveStopWatchStateEnabled());
    layout()->addWidget(m_saveStopWatchState);

    m_savePhoneticSearchState = new QCheckBox(tr("Auswahl zur phonetischen Suche"));
    m_savePhoneticSearchState->setChecked(m_settings->savePhoneticSearchStateEnabled());
    layout()->addWidget(m_savePhoneticSearchState);

    layout()->addStretch();

    QHBoxLayout *resetLayout = new QHBoxLayout;
    layout()->addLayout(resetLayout);
    resetLayout->addStretch();
    QPushButton *resetButton = new QPushButton(tr("Zurücksetzen"));
    connect(resetButton, &QPushButton::clicked, this, &SaveOnClosePage::restoreDefaultValues);
    resetLayout->addWidget(resetButton);
}

void SaveOnClosePage::saveSettings()
{
    m_settings->enableSaveMainWindowGeometry(m_saveWindowGeometry->isChecked());
    m_settings->enableSaveMainWindowState(m_saveWindowState->isChecked());
    m_settings->enableSaveLastDbPath(m_saveLastDbPath->isChecked());
    m_settings->enableSaveStopWatchState(m_saveStopWatchState->isChecked());
    m_settings->enableSavePhoneticSearchState(m_savePhoneticSearchState->isChecked());
}

void SaveOnClosePage::restoreDefaultValues()
{
    m_saveWindowGeometry->setChecked(true);
    m_saveWindowState->setChecked(true);
    m_saveLastDbPath->setChecked(true);
    m_saveStopWatchState->setChecked(true);
    m_savePhoneticSearchState->setChecked(true);
}
