/* SPDX-FileCopyrightText: 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

// Local includes
#include "ExpandingLabel.h"

// Qt includes
#include <QDebug>

ExpandingLabel::ExpandingLabel(QWidget *parent) : QLabel(parent)
{
    setAlignment(Qt::AlignHCenter | Qt::AlignVCenter);
    setSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored);
    setMinimumHeight(15);
}

void ExpandingLabel::resizeText()
{
    QString text = this->text();
    if (text.isEmpty()) {
        return;
    }

    QRect labelSpace = contentsRect();
    QFont font = this->font();

    int size = 0;
    const auto steps = { 100, 50, 25, 10, 5, 1 };
    for (int step : steps) {
        while (true) {
            size += step;
            font.setPointSize(size);
            QFontMetrics fontMetrics(font);
            QRect targetSpace = fontMetrics.boundingRect(text);

            if (targetSpace.height() > labelSpace.height()
                || targetSpace.width() > labelSpace.width()) {

                size -= step;
                break;
            }
        }
    }

    setFont(font);
}

void ExpandingLabel::resizeEvent(QResizeEvent *event)
{
    QLabel::resizeEvent(event);
    resizeText();
}
