/* SPDX-FileCopyrightText: 2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

// Local includes
#include "ChecksumHelper.h"

// Qt includes
#include <QCryptographicHash>

static const QChar s_space = QLatin1Char(' ');

ChecksumHelper::ChecksumHelper(QObject *parent) : QObject(parent)
{
}

void ChecksumHelper::addData(const QString &data)
{
    m_data.append(data);
    m_data.append(s_space);
}

void ChecksumHelper::addData(int data)
{
    m_data.append(QString::number(data));
    m_data.append(s_space);
}

void ChecksumHelper::addData(const Draw::Seat &seat)
{
    m_data.append(QString::number(seat.table));
    m_data.append(s_space);
    m_data.append(QString::number(seat.pair));
    m_data.append(s_space);
}

QString ChecksumHelper::checksum() const
{
    QCryptographicHash hash(QCryptographicHash::Md5);
    hash.addData(m_data.toUtf8());
    return QLatin1String(hash.result().toHex());
}
