/* SPDX-FileCopyrightText: 2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

// Local includes
#include "DefeatableMessageBox.h"

// Qt includes
#include <QCheckBox>

DefeatableMessageBox::DefeatableMessageBox(QObject *parent) : QObject(parent)
{
}

bool DefeatableMessageBox::dontAsk(DefeatableMessageBoxes::BoxId id) const
{
    return m_dontAsk[id];
}

void DefeatableMessageBox::setDontAsk(DefeatableMessageBoxes::BoxId id, bool state)
{
    m_dontAsk[id] = state;
}

QMessageBox::StandardButton DefeatableMessageBox::show(DefeatableMessageBoxes::BoxId id,
                                                       QWidget *parent,
                                                       const QString &title, const QString &text,
                                                       QMessageBox::StandardButton defaultButton)
{
    auto *dontAsk = new QCheckBox(tr("Nicht mehr nachfragen"));
    dontAsk->setChecked(true);
    QMessageBox messageBox(parent);
    messageBox.setIcon(QMessageBox::Question);
    messageBox.setWindowTitle(title);
    messageBox.setText(text);
    messageBox.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
    messageBox.setDefaultButton(defaultButton);
    messageBox.setCheckBox(dontAsk);

    const auto result = static_cast<QMessageBox::StandardButton>(messageBox.exec());
    m_dontAsk[id] = dontAsk->isChecked();

    return result;
}
