/* SPDX-FileCopyrightText: 2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

#ifndef DRAW_H
#define DRAW_H

namespace Draw
{

constexpr int settingsVersion = 1;

struct Settings
{
    bool consecutive;
    int tablesLimit;
    int randomDraw;
    int windowDraw;
    int consecutiveDraw;
};

const auto defaultSettings = Settings {
    false, // consecutive
    -1,    // tablesLimit
    -1,    // randomDraw
    4,     // windowDraw
    -1     // consecutiveDraw
};

struct Seat
{
    int table = 0;
    int pair = 0;

    bool isEmpty() const
    {
        return this->table == 0;
    }

    bool operator==(const Seat &other) const
    {
        return this->table == other.table && this->pair == other.pair;
    }

    bool operator!=(const Seat &other) const
    {
        return this->table != other.table || this->pair != other.pair;
    }
};

const auto EmptySeat = Seat { 0, 0 };

int indexForPair(int pair);
int indexForPlayer(int pair, int player);
int otherPair(int pair);
int pairForIndex(int index);
int playerForIndex(int index);

}

#endif // DRAW_H
