/* SPDX-FileCopyrightText: 2019-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

#ifndef JSONHELPER_H
#define JSONHELPER_H

// Local includes
#include "Markers.h"
#include "RegistrationColumns.h"
#include "Draw.h"
#include "OptionalPages.h"

// Qt classes
class QJsonObject;
class QJsonArray;
class QString;

namespace JsonHelper
{

QString serializeJson(const QJsonObject &json);
QString serializeJson(const QJsonArray &json);
QJsonObject jsonObjectFromString(const QString &data);
QJsonArray jsonArrayFromString(const QString &data);

QString singlesManagementToString(const Markers::SinglesManagement &data);
QJsonObject singlesManagementToJson(const Markers::SinglesManagement &data);
Markers::SinglesManagement parseSinglesManagement(const QString &data);
Markers::SinglesManagement parseSinglesManagement(const QJsonObject &jsonObject);

QString registrationColumnsToString(const QVector<RegistrationColumns::Column> &columns);
QJsonArray registrationColumnsToJson(const QVector<RegistrationColumns::Column> &columns);
QVector<RegistrationColumns::Column> parseRegistrationColumns(const QString &data);
QVector<RegistrationColumns::Column> parseRegistrationColumns(const QJsonArray &jsonArray);

QString drawSettingsToString(const Draw::Settings &settings);
QJsonObject drawSettingsToJson(const Draw::Settings &settings);
Draw::Settings parseDrawSettings(const QString &data);
Draw::Settings parseDrawSettings(const QJsonObject &jsonObject);

QString optionalPagesToString(const QVector<OptionalPages::Page> &pages);
QJsonArray optionalPagesToJson(const QVector<OptionalPages::Page> &pages);
QVector<OptionalPages::Page> parseOptionalPages(const QString &data);
QVector<OptionalPages::Page> parseOptionalPages(const QJsonArray &json);

// Legacy functions needed for updates
QVector<RegistrationColumns::Column> parsePlayersPageColumns(const QString &data);
QVector<RegistrationColumns::Column> parsePlayersPageColumns(const QJsonObject &jsonObject);

}

#endif // JSONHELPER_H
