/* SPDX-FileCopyrightText: 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

// Local includes
#include "StringTools.h"

// Qt includes
#include <QDebug>
#include <QCollator>

StringTools::StringTools(QObject *parent, const QString *boogerSymbol)
    : QObject(parent), m_boogerSymbol(boogerSymbol)
{
    m_locale = QLocale::system();
    m_collator.setLocale(m_locale);
    m_collator.setCaseSensitivity(Qt::CaseInsensitive);
}

QString StringTools::toLower(const QString &text) const
{
    return m_locale.toLower(text);
}

QString StringTools::toUpper(const QString &text) const
{
    return m_locale.toUpper(text);
}

void StringTools::setBoogerScore(int score)
{
    m_boogerScore = score;
}

QString StringTools::boogify(int score) const
{
    return score == m_boogerScore ? QString::number(score)
                                  : QStringLiteral("%1 %2").arg(QString::number(score),
                                                                *m_boogerSymbol);
}

QString StringTools::locale() const
{
    return m_locale.name();
}

QString StringTools::defaultLocale() const
{
    return QLocale::system().name();
}

void StringTools::setLocale(const QString &name)
{
    m_locale = QLocale(name);
    m_collator.setLocale(m_locale);
    m_localeChanged = true;
}

bool StringTools::resetLocale()
{
    if (! m_localeChanged) {
        return false;
    }

    m_locale = QLocale::system();
    m_collator.setLocale(m_locale);
    m_localeChanged = false;
    return true;
}

bool StringTools::localeChanged() const
{
    return m_localeChanged;
}

QString StringTools::dateFormat() const
{
    QString dateFormat = m_locale.dateFormat(QLocale::ShortFormat);
    return dateFormat.contains(QStringLiteral("yyyy"))
        ? dateFormat
        : dateFormat.replace(QStringLiteral("yy"), QStringLiteral("yyyy"));
}

QString StringTools::timeFormat() const
{
    return m_locale.timeFormat(QLocale::ShortFormat);
}
