/* SPDX-FileCopyrightText: 2018-2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

#ifndef TITLEDIALOG_H
#define TITLEDIALOG_H

// Qt includes
#include <QDialog>
#include <QDialogButtonBox>
#include <QPushButton>

// Qt classes
class QVBoxLayout;
class QLabel;

class TitleDialog : public QDialog
{
    Q_OBJECT

public:
    enum DeleteMode {
        DeleteOnClose,
        NoDelete
    };

    void setTitle(const QString &title);
    void resizeToContents();

    void addButtonBox();
    void addButtonBox(QDialogButtonBox::StandardButtons buttons);
    void setOkButtonText(const QString &text);
    bool okButtonEnabled() const;
    void setButtonText(QDialogButtonBox::StandardButton button, const QString &text);

public slots:
    void setOkButtonEnabled(bool state);

signals:
    void updateStatus(const QString &text);

protected:
    explicit TitleDialog(QWidget *parent, DeleteMode deleteMode = DeleteMode::DeleteOnClose);
    QVBoxLayout *mainLayout() const;
    QVBoxLayout *layout() const;
    QDialogButtonBox *buttonBox() const;

protected slots:
    void accept() override;

private: // Variables
    QVBoxLayout *m_mainLayout;
    QVBoxLayout *m_layout;
    QLabel *m_title;
    QDialogButtonBox *m_buttonBox;

};

#endif // TITLEDIALOG_H
