/* SPDX-FileCopyrightText: 2020 Tobias Leupold <tobias.leupold@gmx.de>

   SPDX-License-Identifier: GPL-3.0-or-later
*/

#ifndef TOURNAMENTTEMPLATE_H
#define TOURNAMENTTEMPLATE_H

#include "Tournament.h"
#include "RegistrationColumns.h"
#include "Draw.h"
#include "DefaultValues.h"
#include "OptionalPages.h"

namespace TournamentTemplate
{

constexpr int version = 3;

struct Settings
{
    Tournament::Mode tournamentMode;
    Tournament::ScoreType scoreType;
    int boogerScore;
    int boogersPerRound;
    Draw::Settings drawSettings;
    QVector<RegistrationColumns::Column> registrationColumns;
    bool registrationListHeaderHidden;
    bool autoSelectPairs;
    bool selectByLastRound;
    bool noTableNumbers;
    bool includeOpponentGoals;
    bool grayOutUnimportantGoals;
    QVector<OptionalPages::Page> optionalPages;
};

const Settings defaultSettings {
    Tournament::Mode::FixedPairs,        // tournamentMode
    Tournament::ScoreType::Horizontal,   // scoreType
    DefaultValues::boogerScore,          // boogerScore
    DefaultValues::boogersPerRound,      // boogersPerRound
    Draw::defaultSettings,               // drawSettings
    RegistrationColumns::defaultColumns, // registrationColumns
    false,                               // registrationListHeaderHidden
    true,                                // autoSelectPairs
    true,                                // selectByLastRound
    false,                               // noTableNumbers
    true,                                // includeOpponentGoals
    true,                                // grayOutUnimportantGoals
    { }                                  // optionalPages
};

}

#endif // TOURNAMENTTEMPLATE_H
